import { select } from 'd3';
import './styles.css';

const menuOptions = [
  { value: 'volvo', text: 'Volvo' },
  { value: 'saab', text: 'Saab' },
  { value: 'mercedes', text: 'Mercedes' },
  { value: 'audi', text: 'Audi' },
];

export const main = (container, { state, setState }) => {
  // Create the D3 selection for the container,
  // and give a class so we can style it in `styles.css`.
  const containerSelection = select(container).attr(
    'class',
    'ui-elements-container',
  );

  // Initialize `state.selectedValue` to "volvo".
  if (state.selectedMenuValue === undefined) {
    // setState((state) => ({ ...state, count: 0 }));
    setState((state) => ({
      ...state,
      selectedMenuValue: menuOptions[0].value,
    }));
    return;
  }

  // Create the menu
  const menu = containerSelection
    .selectAll('select')
    .data([null])
    .join('select')
    .attr('class', 'form-control')
    .on('change', (event) => {
      setState((state) => ({
        ...state,
        selectedMenuValue: event.target.value,
      }));
    });

  // Fill out the options
  menu
    .selectAll('option')
    .data(menuOptions)
    .join('option')
    .attr('value', (option) => option.value)
    .text((option) => option.text)
    .property(
      'selected',
      (option) => option.value === state.selectedMenuValue,
    );

  // Display the selected value as text
  const { selectedMenuValue } = state;
  containerSelection
    .selectAll('div.message')
    .data([null])
    .join('div')
    .attr('class', 'message')
    .text(`You've selected ${selectedMenuValue}.`);
};
